pub struct Cmap6<'a> {
data: FontData<'a>,
}Expand description
cmap Format 6: Trimmed table mapping
Fields
data: FontData<'a>Implementations
Sourceimpl<'a> Cmap6<'a>
impl<'a> Cmap6<'a>
pub const MIN_SIZE: usize
Sourcepub fn resolve_offset<O: Offset, R: FontRead<'a>>(
&self,
offset: O,
) -> Result<R, ReadError>
pub fn resolve_offset<O: Offset, R: FontRead<'a>>( &self, offset: O, ) -> Result<R, ReadError>
Resolve the provided offset from the start of this table.
Sourcepub fn offset_data(&self) -> FontData<'a>
pub fn offset_data(&self) -> FontData<'a>
Return a reference to this table’s raw data.
We use this in the compile crate to resolve offsets.
Sourcepub fn shape(&self) -> &Self
👎Deprecated: just use the base type directly
pub fn shape(&self) -> &Self
Return a reference to the table’s ‘Shape’ struct.
This is a low level implementation detail, but it can be useful in some cases where you want to know things about a table’s layout, such as the byte offsets of specific fields.
Sourcepub fn language(&self) -> u16
pub fn language(&self) -> u16
For requirements on use of the language field, see “Use of the language field in ‘cmap’ subtables” in this document.
Sourcepub fn first_code(&self) -> u16
pub fn first_code(&self) -> u16
First character code of subrange.
Sourcepub fn entry_count(&self) -> u16
pub fn entry_count(&self) -> u16
Number of character codes in subrange.
Sourcepub fn glyph_id_array(&self) -> &'a [BigEndian<u16>]
pub fn glyph_id_array(&self) -> &'a [BigEndian<u16>]
Array of glyph index values for character codes in the range.
pub fn format_byte_range(&self) -> Range<usize> ⓘ
pub fn length_byte_range(&self) -> Range<usize> ⓘ
pub fn language_byte_range(&self) -> Range<usize> ⓘ
pub fn first_code_byte_range(&self) -> Range<usize> ⓘ
pub fn entry_count_byte_range(&self) -> Range<usize> ⓘ
pub fn glyph_id_array_byte_range(&self) -> Range<usize> ⓘ