pub struct Cmap13<'a> {
data: FontData<'a>,
}Expand description
cmap Format 13: Many-to-one range mappings
Fields
data: FontData<'a>Implementations
Sourceimpl<'a> Cmap13<'a>
impl<'a> Cmap13<'a>
pub const MIN_SIZE: usize
Sourcepub fn resolve_offset<O: Offset, R: FontRead<'a>>(
&self,
offset: O,
) -> Result<R, ReadError>
pub fn resolve_offset<O: Offset, R: FontRead<'a>>( &self, offset: O, ) -> Result<R, ReadError>
Resolve the provided offset from the start of this table.
Sourcepub fn offset_data(&self) -> FontData<'a>
pub fn offset_data(&self) -> FontData<'a>
Return a reference to this table’s raw data.
We use this in the compile crate to resolve offsets.
Sourcepub fn shape(&self) -> &Self
👎Deprecated: just use the base type directly
pub fn shape(&self) -> &Self
Return a reference to the table’s ‘Shape’ struct.
This is a low level implementation detail, but it can be useful in some cases where you want to know things about a table’s layout, such as the byte offsets of specific fields.
Sourcepub fn language(&self) -> u32
pub fn language(&self) -> u32
For requirements on use of the language field, see “Use of the language field in ‘cmap’ subtables” in this document.
Sourcepub fn num_groups(&self) -> u32
pub fn num_groups(&self) -> u32
Number of groupings which follow
Sourcepub fn groups(&self) -> &'a [ConstantMapGroup]
pub fn groups(&self) -> &'a [ConstantMapGroup]
Array of ConstantMapGroup records.
pub fn format_byte_range(&self) -> Range<usize> ⓘ
pub fn reserved_byte_range(&self) -> Range<usize> ⓘ
pub fn length_byte_range(&self) -> Range<usize> ⓘ
pub fn language_byte_range(&self) -> Range<usize> ⓘ
pub fn num_groups_byte_range(&self) -> Range<usize> ⓘ
pub fn groups_byte_range(&self) -> Range<usize> ⓘ
Sourceimpl<'a> Cmap13<'a>
impl<'a> Cmap13<'a>
Sourcepub fn map_codepoint(&self, codepoint: impl Into<u32>) -> Option<GlyphId>
pub fn map_codepoint(&self, codepoint: impl Into<u32>) -> Option<GlyphId>
Maps a codepoint to a nominal glyph identifier.
Sourcepub fn iter(&self) -> Cmap13Iter<'a> ⓘ
pub fn iter(&self) -> Cmap13Iter<'a> ⓘ
Returns an iterator over all (codepoint, glyph identifier) pairs in the subtable.
Malicious and malformed fonts can produce a large number of invalid
pairs. Use Self::iter_with_limits to generate a pruned sequence
that is limited to reasonable values.
Sourcepub fn iter_with_limits(&self, limits: CmapIterLimits) -> Cmap13Iter<'a> ⓘ
pub fn iter_with_limits(&self, limits: CmapIterLimits) -> Cmap13Iter<'a> ⓘ
Returns an iterator over all (codepoint, glyph identifier) pairs in the subtable within the given limits.